@@ -64,10 +64,7 @@ struct _EogSidebarPrivate {
 	GtkTreeModel *page_model;
 };
 
-G_DEFINE_TYPE (EogSidebar, eog_sidebar, GTK_TYPE_BOX)
-
-#define EOG_SIDEBAR_GET_PRIVATE(object) \
-	(G_TYPE_INSTANCE_GET_PRIVATE ((object), EOG_TYPE_SIDEBAR, EogSidebarPrivate))
+G_DEFINE_TYPE_WITH_PRIVATE (EogSidebar, eog_sidebar, GTK_TYPE_BOX)
 
 static void
 eog_sidebar_destroy (GtkWidget *object)
@@ -185,8 +182,6 @@ eog_sidebar_class_init (EogSidebarClass *eog_sidebar_class)
 	g_object_class = G_OBJECT_CLASS (eog_sidebar_class);
 	widget_class = GTK_WIDGET_CLASS (eog_sidebar_class);
 
-	g_type_class_add_private (g_object_class, sizeof (EogSidebarPrivate));
-
 	widget_class->destroy = eog_sidebar_destroy;
 	g_object_class->get_property = eog_sidebar_get_property;
 	g_object_class->set_property = eog_sidebar_set_property;
@@ -373,7 +368,7 @@ eog_sidebar_init (EogSidebar *eog_sidebar)
 	gtk_orientable_set_orientation (GTK_ORIENTABLE (eog_sidebar),
 					GTK_ORIENTATION_VERTICAL);
 
-	eog_sidebar->priv = EOG_SIDEBAR_GET_PRIVATE (eog_sidebar);
+	eog_sidebar->priv = eog_sidebar_get_instance_private (eog_sidebar);
 
 	/* data model */
 	eog_sidebar->priv->page_model = (GtkTreeModel *)
@@ -429,8 +424,8 @@ eog_sidebar_init (EogSidebar *eog_sidebar)
 			  G_CALLBACK (eog_sidebar_close_clicked_cb),
 			  eog_sidebar);
 
-	image = gtk_image_new_from_stock (GTK_STOCK_CLOSE,
-					  GTK_ICON_SIZE_MENU);
+	image = gtk_image_new_from_icon_name ("window-close",
+					      GTK_ICON_SIZE_MENU);
 	gtk_container_add (GTK_CONTAINER (close_button), image);
 	gtk_widget_show (image);
 
@@ -486,7 +481,7 @@ eog_sidebar_add_page (EogSidebar   *eog_sidebar,
 	index = gtk_notebook_append_page (GTK_NOTEBOOK (eog_sidebar->priv->notebook),
 					  main_widget, NULL);
 
-	menu_item = gtk_image_menu_item_new_with_label (title);
+	menu_item = gtk_menu_item_new_with_label (title);
 
 	g_signal_connect (menu_item, "activate",
 			  G_CALLBACK (eog_sidebar_menu_item_activate_cb),
